@@ -510,7 +510,9 @@ class mCalendar:
             else:
               ds = start_datetime.strftime(start_format)+'\n'+end_datetime.strftime(end_format)
               de = end_datetime.strftime(end_format)
-               
+              
+            if self.current_view == 0:
+              start_datetime = self.current_datetime.replace(hour=start_datetime.hour,minute=start_datetime.minute)
               
             self.event_list.append((start_datetime,(ds,de,description,uuid,d1,d2,fg,bg)))                
           else:
@@ -850,8 +852,8 @@ class mCalendar:
               #reccuring
               where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Day(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND ((julianday("'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'")-(julianday(start))) % repeatvalue)=0.0 ) '
               where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Week(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND ((julianday("'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'")-(julianday(start))) % (repeatvalue*7))=0.0 ) '
-              where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Month(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND strftime("%d",start)='+str(self.view_datetime.day)+' AND (('+str((self.view_datetime.year*12)+self.view_datetime.month)+'-(strftime("%m",start)+(strftime("%Y",start)*12))) % (repeatvalue))==0 ) '
-              where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Year(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND strftime("%d",start)='+str(self.view_datetime.day)+' AND strftime("%m",start)='+str(self.view_datetime.month)+' AND (('+str((self.view_datetime.year))+'-((strftime("%Y",start)))) % (repeatvalue))==0 ) '
+              where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Month(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND strftime("%d",start)="'+(self.view_datetime.strftime("%d"))+'" AND (('+str((self.view_datetime.year*12)+self.view_datetime.month)+'-(strftime("%m",start)+(strftime("%Y",start)*12))) % (repeatvalue))==0 ) '
+              where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Year(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND strftime("%d",start)="'+(self.view_datetime.strftime("%d"))+'" AND strftime("%m",start)='+self.view_datetime.strftime("%m")+' AND (('+str((self.view_datetime.year))+'-((strftime("%Y",start)))) % (repeatvalue))==0 ) '
               where = where + ')'
 
             elif self.current_view==1:
@@ -935,15 +937,15 @@ class mCalendar:
                     d = start_datetime
                     de = end_datetime
                     while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
-                      if (d.strftime("%W")==self.view_datetime.strftime("%W")):
+                      if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%W")==self.view_datetime.strftime("%W")):
                         self.appendToView(d,WEEK_VIEW_FORMAT,de,WEEK_VIEW_FORMAT,event[2],event[3],"","",self.get_fg_color(event[9]),self.get_bg_color())
                       d = addMonth(d,repeatvalue) 
-                      de = addMonth(d,repeatvalue)
+                      de = addMonth(de,repeatvalue)
                   elif frequency=="Year(s)":
                     d = start_datetime
                     de = end_datetime
                     while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
-                      if ((d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%W")==self.view_datetime.strftime("%W"))) :
+                      if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%W")==self.view_datetime.strftime("%W")) :
                         self.appendToView(d,WEEK_VIEW_FORMAT,de,WEEK_VIEW_FORMAT,event[2],event[3],"","",self.get_fg_color(event[9]),self.get_bg_color())
                       d = addMonth(d,repeatvalue*12) 
                       de = addMonth(de,repeatvalue*12)
@@ -957,7 +959,7 @@ class mCalendar:
                     d = start_datetime
                     de = end_datetime
                     while (d.date() <= until.date()) and (d <= endMonth(self.view_datetime)):
-                      if (d.strftime("%m")==self.view_datetime.strftime("%m")) and (self.view_datetime.weekday() in googleToDays(byday)):
+                      if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%m")==self.view_datetime.strftime("%m")) and (self.view_datetime.weekday() in googleToDays(byday)):
                         self.appendToView(d,MONTH_VIEW_FORMAT,de,MONTH_VIEW_FORMAT,event[2],event[3],"","",self.get_fg_color(event[9]),self.get_bg_color())
                       d = d+diff         
                       de = de + diff
@@ -966,7 +968,7 @@ class mCalendar:
                     d = start_datetime
                     de = end_datetime
                     while (d.date() <= until.date()) and (d <= endMonth(self.view_datetime)):
-                      if (d.strftime("%m")==self.view_datetime.strftime("%m")) and (self.view_datetime.weekday() in googleToDays(byday)):
+                      if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%m")==self.view_datetime.strftime("%m")) and (self.view_datetime.weekday() in googleToDays(byday)):
                         self.data.store.append(eventToList(d,MONTH_VIEW_FORMAT,de,MONTH_VIEW_FORMAT,event[2],event[3],"","",self.get_fg_color(event[9]),self.get_bg_color()))
                       d = d+diff            
                       de = de + diff
@@ -975,16 +977,16 @@ class mCalendar:
                     d = start_datetime
                     de = end_datetime
                     while (d.date() <= until.date()) and (d <= endMonth(self.view_datetime)):
-                      if (d.strftime("%m")==self.view_datetime.strftime("%m")) :
+                      if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%m")==self.view_datetime.strftime("%m")) :
                         self.appendToView(d,MONTH_VIEW_FORMAT,de,MONTH_VIEW_FORMAT,event[2],event[3],"","",self.get_fg_color(event[9]),self.get_bg_color())
                       d = addMonth(d,repeatvalue)        
-                      de = addMonth(d,repeatvalue)        
+                      de = addMonth(de,repeatvalue)        
                   elif frequency=="Year(s)":
                     debug('test')
                     d = start_datetime
                     de = end_datetime
                     while (d.date() <= until.date()) and (d <= endMonth(self.view_datetime)):
-                      if ((d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%m")==self.view_datetime.strftime("%m"))):
+                      if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%m")==self.view_datetime.strftime("%m")):
                         self.appendToView(d,MONTH_VIEW_FORMAT,de,MONTH_VIEW_FORMAT,event[2],event[3],"","",self.get_fg_color(event[9]),self.get_bg_color())
                       d = addMonth(d,repeatvalue*12)  
                       de = addMonth(de,repeatvalue*12)  
