@@ -55,9 +55,6 @@ class Event:
             self.alarm = False
             self.alarm_value = 0
             self.alarm_id = 0
-            print 'test'
-            print start
-            print suuid
 
             if suuid=="":
               self.uuid = uuid.uuid4().__str__()
@@ -114,7 +111,7 @@ class Event:
               d = self.start_datetime - diff
               self.alarm_id = osso.alarmd.add_alarm(time.mktime(d.timetuple()),title=strip_accents(self.description))
               debug(self.alarm_id)
-              
+
             if self.cal_id == None:
               self.cal_id = "default"
 
